<?php

/**
 * @file
 * The Views row style plugin class. Very simple because it 'uses fields'.
 *
 * @see views_custom_template_views_plugins()
 */

class views_plugin_row_custom_template extends views_plugin_row {

  /**
   * Default options.
   */
  function option_definition() {
    $options = parent::option_definition();
    $options['function'] = array('default' => '');
    $options['field_name_mapping'] = array('default' => array());
    $options['hide_empty'] = array('default' => FALSE);
    return $options;
  }

  /**
   * Provide a form for setting options.
   */
  function options_form(&$form, &$form_state) {
    parent::options_form($form, $form_state);

    $form['function'] = array(
      '#title' => t('Template function'),
      '#type' => 'textfield',
      '#required' => TRUE,
      '#default_value' => isset($this->options['function']) ? $this->options['function'] : '',
      '#description' => t('This function name will be converted to a template file and resolved in the active theme. (Think theme function and preprocessor.)'),
    );

    $fields = $this->display->handler->get_option('fields');
    $field_labels = $this->display->handler->get_field_labels();

    $form['field_name_mapping'] = array(
      '#type' => 'fieldset',
      '#title' => t('Field name mapping'),
      '#description' => t('Mapped fields will be available in <code>$content</code> with their new name.') . ' ' . t('Excluded fields will not be available in <code>$content</code>.'),
      '#collapsible' => FALSE,
      '#tree' => TRUE,
    );
    foreach ($fields as $from => $field) {
      if (!$field['exclude']) {
        $form['field_name_mapping'][$from] = array(
          '#type' => 'textfield',
          '#title' => t('Field: %field_id (%field_label)', array('%field_id' => $from, '%field_label' => $field_labels[$from])),
          '#default_value' => isset($this->options['field_name_mapping'][$from]) ? $this->options['field_name_mapping'][$from] : '',
        );
      }
    }

    $form['hide_empty'] = array(
      '#type' => 'checkbox',
      '#title' => t('Hide empty fields'),
      '#default_value' => $this->options['hide_empty'],
      '#description' => t('Do not display fields, labels or markup for fields that are empty.'),
    );
  }

  /**
   * Provide a full list of possible theme templates used by this style.
   */
  function theme_functions() {
    $default = parent::theme_functions();
    array_unshift($default, 'custom_template__' . $this->options['function']);
    return $default;
  }

}
